@@ -18,12 +18,19 @@ has 'ok' => (
     isa => 'Bool',
     default => 1,
 );
+
 has 'ready' => (
     is => 'rw',
     isa => 'Bool',
     default => 1,
 );
 
+has 'scheme' => (
+    is => 'ro',
+    isa => 'Str',
+    default => 'http',
+);
+
 sub prepare {
     my ($self) = @_;    
     # would be nice to test if it's valid before connecting...
