@@ -5,4 +5,10 @@ use Moose;
 
 use namespace::autoclean;
 
+has 'scheme' => (
+    is => 'ro',
+    isa => 'Str',
+    default => 'https',
+);
+
 __PACKAGE__->meta->make_immutable;
